@@ -36,7 +36,7 @@ def clear_em_cookie():
 
 @lru_cache(maxsize=None)
 def get_xue_qiu_cookie():
-    stock_account_info = mongodb_util.find_query_data('stock_account_info', {"type": "xue_qiu", })
+    stock_account_info = mongodb_util.find_query_data('stock_account_info', {"type": "xue_qiu_cookie", })
     cookie = list(stock_account_info['cookie'])[0]
     return cookie
 
