@@ -183,3 +183,8 @@ THS_STOCK_INDUSTRY_DETAIL = 'ths_stock_industry_detail'
 
 # 年k线前复权
 STOCK_QFQ_YEAR = 'stock_qfq_year'
+
+# 主线集合
+MAIN_LINE_LIST = 'main_line_list'
+# 主线详情
+MAIN_LINE_DETAIL = 'main_line_detail'
